<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'تفعيل الملحق',
	'affichage' => 'عرض',
	'aide_non_disponible' => 'هذا القسم من التعليمات الفورية غير متوافر حالياً بهذه اللغة.',
	'annuler_recherche' => 'إلغاء البحث',
	'auteur' => 'المؤلف:',
	'avis_acces_interdit' => 'الدخول محظور',
	'avis_acces_interdit_prive' => 'ليس لديكم الأذونات الكافية للدخول الى الصفح <b>@exec@</b>.',
	'avis_article_modifie' => 'تحذير، @nom_auteur_modif@ عمل على هذا المقال منذ @date_diff@ دقيقة',
	'avis_aucun_resultat' => 'لا توجد نتائج.',
	'avis_base_inaccessible' => 'لا يمكن الاتصال بقاعدة بيانات @base@.',
	'avis_chemin_invalide_1' => 'لا يبدو المسار',
	'avis_chemin_invalide_2' => 'الذي حددته صالحاً. الرجاء العودة الى الصفحة السابقة والتأكد من المعلومات المدخلة. والتأكد من المعلومات المدخلة.',
	'avis_connexion_echec_1' => 'فشل الاتصال بقاعدة البيانات.',
	'avis_connexion_echec_2' => 'عد الى الصفحة السابقة وتأكد من صحة المعلومات التي أدخلتها.',
	'avis_connexion_echec_3' => '<b>ملاحظة</b> في العديد من اجهزة الخدمة، عليك <b>بطلب</b> تفعيل الدخول الى قاعدة البيانات قبل التمكن من استخدامها. اذا لم تتمكن من الاتصال بالقاعدة، تأكد من انك نفذت هذه الخطوة.',
	'avis_connexion_erreur_creer_base' => 'لم يتم إنشاء قاعدة البيانات',
	'avis_connexion_erreur_fichier_cle_manquant_1' => 'المشرف على الموقع هو الذي ينفذ التثبيت مع نسخة احتياطية للمفاتيح وكلمة السر الخاصة به ',
	'avis_connexion_erreur_fichier_cle_manquant_2' => 'المشرف على الموقع هو الذي ينفذ التثبيت مع نسخة احتياطية للمفاتيح',
	'avis_connexion_erreur_nom_base' => 'لا يجب ان يحتوي اسم القاعدة الا احرف وأرقام',
	'avis_connexion_ldap_echec_1' => 'الاتصال بخادم LDAP فشل.',
	'avis_connexion_ldap_echec_2' => 'عد الى الصفحة السابقة وتأكد من صحة المعلومات التي أدخلتها.',
	'avis_connexion_ldap_echec_3' => 'وإلا، لا تستخدم دعم LDAP لجلب المستخدمين.',
	'avis_deplacement_rubrique' => 'تحذير! يحتوي هذا القسم على @contient_breves@ خبر@scb@: إذا قمت بنقله، الرجاء تأشير هذا الخيار لتأكيد طلبك.',
	'avis_erreur_connexion_mysql' => 'خطأ اتصالي SQL',
	'avis_erreur_creation_compte' => 'فشل خلال تأصيل الحساب',
	'avis_espace_interdit' => '<b>مجال ممنوع</b> <div>SPIP مثبت مسبقاً.</div>',
	'avis_lecture_noms_bases_1' => 'لم يتمكن المثبت من قراءة أسماء قواعد البيانات المثبتة.',
	'avis_lecture_noms_bases_2' => 'إما لا توجد قاعدة بيانات متوافرة أو تم ايقاف وظيفة عرض قواعد البيانات
لأسباب أمنية (هكذا الحال لدى العديد من المضيفين).',
	'avis_lecture_noms_bases_3' => 'إذا كانت الحال الثانية صحيحة، قد يكون هناك قاعدة بيانات تحمل إسم معرّف الدخول لديك يمكن استخدامها:',
	'avis_non_acces_page' => 'لا تملك إمتياز الدخول الى هذه الصفحة.',
	'avis_operation_echec' => 'العملية فشلت.',
	'avis_operation_impossible' => 'عملية غير ممكنة',
	'avis_suppression_base' => 'تحذير، حذف البيانات لا يمكن التراجع عنه',

	// B
	'bouton_acces_ldap' => 'إضافة الوصول الى LDAP',
	'bouton_ajouter' => 'إضافة',
	'bouton_annuler' => 'الغاء',
	'bouton_cache_activer' => 'إعادة تشغيل الذاكرة المخبأة',
	'bouton_cache_desactiver' => 'إيقاف الذاكرة المخبأة مؤقتاً',
	'bouton_demande_publication' => 'طلب نشر هذا المقال',
	'bouton_desactive_tout' => 'تعطيل الكل',
	'bouton_desinstaller' => 'إزالة التثبيت',
	'bouton_effacer_tout' => 'حذف الكل',
	'bouton_envoyer_message' => 'صيغة نهائية : إرسال',
	'bouton_fermer' => 'إغلاق',
	'bouton_mettre_a_jour_base' => 'تحديث قاعدة البيانات',
	'bouton_modifier' => 'تغيير',
	'bouton_radio_afficher' => 'إظهار',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'الظهور في قائمة المحررين المتصلين',
	'bouton_radio_envoi_annonces_adresse' => 'إرسال الإعلانات الى العنوان:',
	'bouton_radio_envoi_liste_nouveautes' => 'إرسال قائمة بالأخبار',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'عدم الظهور في قائمة المحررين',
	'bouton_radio_non_envoi_annonces_editoriales' => 'عدم إرسال أي إعلان تحرير',
	'bouton_redirection' => 'إعادة توجيه',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'إعادة التأصيل الى القيم القياسية',
	'bouton_relancer_inscription' => 'إعادة تشغيل التسجيل',
	'bouton_relancer_inscriptions' => 'إعادة تشغيل التسجيلات',
	'bouton_relancer_installation' => 'إعادة إطلاق عملية التثبيت',
	'bouton_reset_password' => 'إنشاء كلمة سر جديدة وإرسالها بالبريد الإلكتروني',
	'bouton_suivant' => 'التالي',
	'bouton_tenter_recuperation' => 'محاولة إصلاح',
	'bouton_test_proxy' => 'اختبار الجهاز الوكيل',
	'bouton_vider_cache' => 'تفريغ ذاكرة كاش',

	// C
	'cache_modifiable_webmestre' => 'يتم تعديل هذه القيمة من قبل مسؤول الموقع.',
	'calendrier_synchro' => 'اذا كنت تستخدم برنامج ادارة مواعيد يتوافق مع <b>iCal</b>، يمكنك ان تطابقه مع نشاط هذا الموقع التحريري.',
	'config_activer_champs' => 'تفعيل الحقول التالية',
	'config_choix_base_sup' => 'تحديد قاعدة في هذا الخادم',
	'config_erreur_base_sup' => 'لا يمكن لنظام SPIP الوصول الى لائحة القواعد المتاحة',
	'config_info_base_sup' => 'اذا كان لديك قواعد بيانات اخرى لاستفسارها عبر SPIP، بواسطة خادم SQL الخاص به او بواسطة خادم اخر، تتيح لك الاستمارة ادناه بالإعلان عن تلك القواعد. اذا تركت حقولاً فارغة سيتم استخدام معرّفات الاتصال بقاعدة البيانات الأساسية.',
	'config_info_base_sup_disponibles' => 'قواعد اضافية يمكن استفسارها:',
	'config_info_enregistree' => 'تم حفظ الإعداد الجديد',
	'config_info_logos' => 'اي عنصر من الموقع يمكن ان يملك رمزاً مثل «رمز الحوم» ',
	'config_info_logos_utiliser' => 'استخدام الرموز',
	'config_info_logos_utiliser_non' => 'عدم استخدام الرموز',
	'config_info_logos_utiliser_survol' => 'استخدام رموز الحوم',
	'config_info_logos_utiliser_survol_non' => 'عدم استخدام رموز الحوم',
	'config_info_redirection' => 'بتفعيل هذا الخيار، يمكنك انشاء مقالات افتراضية تشكل مرجعاً بيسطاً لمقالات منشورة في مواقع اخرى او خارج SPIP.',
	'config_redirection' => 'مقالات افتراضية',
	'config_titre_base_sup' => 'الاعلان عن قاعدة اضافية',
	'config_titre_base_sup_choix' => 'اختيار قاعدة اضافية',
	'connexion_ldap' => 'اتصال:',
	'creer_et_associer_un_auteur' => 'إنشاء مؤلف وربطه',

	// D
	'date_mot_heures' => 'ساعات',

	// E
	'ecran_connexion_couleur_principale' => 'اللون الأساسي',
	'ecran_connexion_image_fond' => 'صورة الخلفية',
	'ecran_connexion_image_fond_explication' => 'استخدام صورة (تنسيق JPEG، ١٩٢٠ x ١٠٨٠ نقطة)',
	'ecran_connexion_image_revenir_couleur_defaut' => 'عودة الى اللون الافتراضي',
	'ecran_connexion_titre' => 'شاشة الدخول',
	'ecran_securite' => '+ شاشة الأمان @version@',
	'email' => 'البريد الالكتروني',
	'email_2' => 'البريد الالكتروني :',
	'en_savoir_plus' => 'مزيد من المعلومات',
	'entree_adresse_annuaire' => 'عنوان الدليل',
	'entree_adresse_email' => 'عنوانك الالكتروني',
	'entree_adresse_email_2' => 'عنوان البريد الالكتروني',
	'entree_base_donnee_1' => 'عنوان قاعدة البيانات',
	'entree_base_donnee_2' => '(غالباً ما يتطابق هذا العنوان مع عنوان موقعك وأحياناً قد يكون عبارة «localhost» وأحياناً أخرى يترك فارغاً.)',
	'entree_biographie' => 'سيرتك في بضع كلمات.',
	'entree_chemin_acces' => '<b>إدخال</b> المسار:',
	'entree_cle_pgp' => 'مفتاح PGP لديك',
	'entree_cle_pgp_2' => 'مفتاح PGP',
	'entree_contenu_rubrique' => '(محتوى القسم ببضع كلمات.)',
	'entree_identifiants_connexion' => 'بيانات إتصالك...',
	'entree_identifiants_connexion_2' => 'بيانات الاتصال',
	'entree_informations_connexion_ldap' => 'الرجاء إدخال معلومات الاتصال بدليل LDAP في هذه الاستمارة.
من المفترض أن تكون حصلت على هذه المعلومات من المسؤول عن نظامك
أو شبكتك.',
	'entree_infos_perso' => 'عرّف بنفسك :',
	'entree_infos_perso_2' => 'من هو المؤلف؟',
	'entree_interieur_rubrique' => 'في القسم:	',
	'entree_liens_sites' => '<b>وصلة هايبرتكست<b> (مرجع، موقع للزيارة...)',
	'entree_login' => 'معرّف دخولك',
	'entree_login_connexion_1' => 'معرّف الاتصال',
	'entree_login_connexion_2' => '(أحياناً يتطابق مع معرّف دخول بروتوكول FTP  وأحياناً أخرى يترك فارغاً)',
	'entree_mot_passe' => 'كلمة سرك',
	'entree_mot_passe_1' => 'كلمة سر الاتصال',
	'entree_mot_passe_2' => '(أحياناً يتطابق مع كلمة سر بروتوكول FTPوأحياناً أخرى يترك فارغاً)',
	'entree_nom_fichier' => 'الرجاء إدخال اسم الملف @texte_compresse@:',
	'entree_nom_pseudo' => 'الإسم او اللقب',
	'entree_nom_pseudo_1' => '(الإسم او اللقب)',
	'entree_nom_pseudo_2' => 'الاسم او اللقب',
	'entree_nom_site' => 'إسم موقعك',
	'entree_nom_site_2' => 'اسم موقع المؤلف',
	'entree_nouveau_passe' => 'كلمة السر الجديدة',
	'entree_passe_ldap' => 'كلمة السر',
	'entree_port_annuaire' => 'رقم منفذ الدليل',
	'entree_signature' => 'التوقيع',
	'entree_titre_obligatoire' => '<b>العنوان</b> [إجباري]<br />',
	'entree_url' => 'عنوان موقعك',
	'entree_url_2' => 'عنوان الموقع',
	'erreur_connect_deja_existant' => 'يوجد حالياً جهاز خدمة بهذا الاسم',
	'erreur_contenu_suspect' => 'تركيبة النص غير سليمة ',
	'erreur_email_deja_existant' => 'هذا العنوان الالكتروني مسجل مسبقاً',
	'erreur_nom_connect_incorrect' => 'هذا الاسم لجهاز الخدمة غير مسموح به',
	'erreur_plugin_attribut_balise_manquant' => 'الخاصية @attribut@ غير موجودة في علامة @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'فشل الغاء تثبيت الملحق. ولكن يمكنك ايقافه.',
	'erreur_plugin_fichier_absent' => 'ملف غير موجود',
	'erreur_plugin_fichier_def_absent' => 'ملف اعداد غير موجود',
	'erreur_plugin_nom_fonction_interdit' => 'اسم دالة غير مسموح به:',
	'erreur_plugin_nom_manquant' => 'اسم الملحق غير الموجود',
	'erreur_plugin_prefix_manquant' => 'حقل تسمية الملحق غير محدد',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; غير موجود في ملف التعريف',
	'erreur_plugin_version_manquant' => 'اصدار الملحق غير موجود',
	'erreur_type_fichier' => 'نوع ملفات غير صحيح',

	// H
	'htaccess_a_simuler' => 'تحذير: إن إعداد خادم HTTP لديك يتجاهل ملفات @htaccess@. لتوفير أمان فعّال لموقعك، يجب تغيير الإعداد بخصوص هذه المسألة، او ان تكون قيم الثوابت @constantes@ (التي يمكن تحديدها في ملف mes_options.php) مجلدات من خارج @document_root@.',
	'htaccess_inoperant' => 'htaccess غير فعّال',

	// I
	'ical_info1' => 'تقدم هذه الصفحة وسائل عدة للاتصال بنشاط الموقع.',
	'ical_info2' => 'لمزيد من المعلومات حول هذه التقنيات يمكنك زيارة <a href="@spipnet@">توثيق SPIP</a>.',
	'ical_info_calendrier' => 'هناك روزتامتان تحت تصرفك. الاولى هي عبارة عن خريطة للموقع تعلن عن كل المقالات المنشورة. اما الثانية، فتحتوي على اعلانات التحرير اضافة الى احدث رسائلك الشخصية: وهي مخصصة لك يحميها مفتاح شخصي يمكنك تغييره في اي وقت يتجديد كلمة سرك.',
	'ical_methode_http' => 'تحميل',
	'ical_methode_webcal' => 'تزامن (webcal://)',
	'ical_texte_js' => 'يتيح لك سطر جافاسكريبت واحد عرض المقالات الحديثة التي تم نشرها في اي موقع يخصك.',
	'ical_texte_prive' => 'تعلمك هذه الروزنامة، المحصورة بالاستخدام الشخصي، بالنشاط التحريري الخاص في هذا الموقع (المهمات والمواعيد الشخصية والاخبار المقترحة...).',
	'ical_texte_public' => 'تتيح لك هذه الروزنامة متابعة النشاط العمومي في هذا الموقع (المقالات والاخبار المنشورة).',
	'ical_texte_rss' => 'يمكنك ترخيص جديد هذا الموقع من خلال اي معالج ملفات بتنسيق XML/RSS (اي RDF Site Summary). وهو ايضاً التنسيق الذي يسمح لـSPIP بقراءة احدث ما ينشر في مواقع اخرى وذلك باستخدام تنسيق تبادل متوافق (مواقع مرخصة). ',
	'ical_titre_js' => 'جافاسكريبت',
	'ical_titre_mailing' => 'القائمة البريدية',
	'ical_titre_rss' => 'ملفات الترخيص',
	'icone_accueil' => 'الأساسية',
	'icone_activer_cookie' => 'وضع كعكة',
	'icone_activite' => 'نشاط الموقع',
	'icone_admin_plugin' => 'ادارة الملحقات',
	'icone_administration' => 'صيانة',
	'icone_afficher_auteurs' => 'إظهار المؤلفين',
	'icone_afficher_visiteurs' => 'عرض الزوار',
	'icone_arret_discussion' => 'إيقاف المشاركة في هذا النقاش',
	'icone_calendrier' => 'الروزنامة',
	'icone_configuration' => 'إعداد',
	'icone_creer_auteur' => 'إضافة مؤلف جديد وإشراكه في هذا المقال',
	'icone_creer_mot_cle' => 'إنشاء مفتاح جديد وربطه بهذا المقال',
	'icone_creer_rubrique_2' => 'إنشاء قسم جديد',
	'icone_developpement' => 'تطوير',
	'icone_edition' => 'تحرير',
	'icone_ma_langue' => 'لغتي',
	'icone_mes_infos' => 'بياناتي',
	'icone_mes_preferences' => 'تفضيلاتي',
	'icone_modifier_article' => 'تعديل هذا المقال',
	'icone_modifier_rubrique' => 'تعديل هذا القسم',
	'icone_publication' => 'نشر',
	'icone_relancer_signataire' => 'تذكير الموقع',
	'icone_retour' => 'رجوع',
	'icone_retour_article' => 'عودة إلى المقال',
	'icone_squelette' => 'صفحات نموذجية',
	'icone_suivi_publication' => 'متابعة النشر',
	'icone_supprimer_cookie' => 'حذف الكعكة',
	'icone_supprimer_rubrique' => 'حذف هذا القسم',
	'icone_supprimer_signature' => 'حذف هذا التوقيع',
	'icone_valider_signature' => 'التصديق على هذا التوقيع',
	'image_administrer_rubrique' => 'يمكنك إدارة هذا القسم',
	'impossible_modifier_login_auteur' => 'لا يمكن تغيير المعرّف.',
	'impossible_modifier_pass_auteur' => 'لا يمكن تغيير كلمة السر.',
	'info_1_article' => 'مقال واحد',
	'info_1_auteur' => 'مؤلف واحد',
	'info_1_message' => 'رسالة واحدة',
	'info_1_mot_cle' => 'مفتاح واحد',
	'info_1_rubrique' => 'قسم واحد',
	'info_1_visiteur' => 'زائر واحد',
	'info_activer_cookie' => 'يمكنك تفعيل <b>كعكة إدارية</b>، تتيح لك 
التنقل بسهولة بين الموقع العمومي والمجال الخاص.',
	'info_activer_menu_developpement' => 'عرض قائمة التطوير',
	'info_admin_etre_webmestre' => 'إعطائي حقوق المشرف',
	'info_admin_je_suis_webmestre' => 'أنا <b>مشرف</b>',
	'info_admin_statuer_webmestre' => 'اعطاء حقوق مسؤول الموقع لهذا المدير',
	'info_admin_webmestre' => 'هذا المدير هو <b>مسؤول الموقع</b>',
	'info_administrateur' => 'مدير',
	'info_administrateur_1' => 'مدير',
	'info_administrateur_2' => 'الموقع (إستخدمه بحذر)',
	'info_administrateur_site_01' => 'اذا كنت احد مدراء هذا الموقع، الرجاء',
	'info_administrateur_site_02' => 'نقر هذه الوصلة',
	'info_administrateurs' => 'مدراء',
	'info_administrer_rubrique' => 'يمكنك إدارة هذا القسم',
	'info_adresse' => 'الى العنوان:',
	'info_adresse_desinscription' => 'عنوان حذف التسجيل :',
	'info_adresse_url' => 'عنوان الموقع العمومي',
	'info_afficher_par_nb' => 'عرض حسب',
	'info_aide_en_ligne' => 'تعليمات SPIP الفورية',
	'info_ajout_image' => 'عندما تضيف صوراً على شكل مستندات مربوطة بمقال ما،
يمكن لـ SPIP ان ينشئ آلياً مصغرات عن
الصور المدرجة. ويتيح ذلك مثلاً، إنشاء
معرض صور او محفظة.',
	'info_ajouter_rubrique' => 'إضافة قسم آخر الى الإدارة:',
	'info_annonce_nouveautes' => 'إعلان عن آخر الأخبار',
	'info_article' => 'مقال',
	'info_article_2' => 'مقال',
	'info_article_a_paraitre' => 'المقالات المؤجلة التي تنتظر النشر',
	'info_articles_02' => 'مقال',
	'info_articles_2' => 'المقالات',
	'info_articles_auteur' => 'مقالات هذا المؤلف',
	'info_articles_miens' => 'مقالاتي',
	'info_articles_tous' => 'كل المقالات',
	'info_articles_trouves' => 'المقالات التي عثر عليها',
	'info_attente_validation' => 'مقالاتك المنتظرة التصديق',
	'info_aucun_article' => 'لا يوجد مقالات',
	'info_aucun_auteur' => 'لا يوجد مؤلفون',
	'info_aucun_message' => 'لا توجد رسائل',
	'info_aucun_rubrique' => 'لا توجد أقسام',
	'info_aujourdhui' => 'اليوم:',
	'info_auteur_gere_rubriques' => 'هذا المؤلف يدير الأقسام التالية:',
	'info_auteur_gere_toutes_rubriques' => 'هذا المؤلف يدير <b>كل الأقسام</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'أدير <b>كل الأقسام</b>',
	'info_auteurs' => 'المؤلفون',
	'info_auteurs_par_tri' => 'المؤلفون@partri@',
	'info_auteurs_trouves' => 'المؤلفون الذين عثر عليهم',
	'info_authentification_externe' => 'التحقق الخارجي',
	'info_avertissement' => 'تحذير',
	'info_barre_outils' => 'مع شريط أدواته؟',
	'info_base_installee' => '<b>تم تثبيت بنية قاعدة البيانات. ',
	'info_bio' => 'السيرة',
	'info_cache_desactive' => 'الذاكرة المخبأة متوقفة مؤقتاً.',
	'info_chapeau' => 'المقدمة',
	'info_chapeau_2' => 'المقدمة:',
	'info_chemin_acces_1' => 'خيارات: <b>مسار الدخول في الدليل</b>',
	'info_chemin_acces_2' => 'من الآن، عليك بإعداد مسار الدخول الى معلومات الدليل. هذه المعلومات أساسية لقراءة بيانات المستخدمين المحفوظة في الدليل.',
	'info_chemin_acces_annuaire' => 'خيارات: <b>مسار الدخول في الدليل</b>',
	'info_choix_base' => 'الخطوة الثالثة: ',
	'info_classement_1' => ' من أصل @liste@ مقال',
	'info_classement_2' => 'من أصل @liste@ مقال',
	'info_code_acces' => 'لا تنسى بيانات الدخول الخاصة بك!',
	'info_config_suivi' => 'اذا كان هذا العنوان يدل الى قائمة بريدية، يمكنك ادخال العنوان حيث يقوم المشاركون في الموفع بتسجيل انفسهم، ادناه. ويمكن لهذا العنوان ان يكون عنوان URL (مثلاً صفحة التسجيل في القائمة عبر النسيج) او عنوان بريدي يحمل موضوعاً محدداً (مثلاً: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'يمكنك الاشتراك في القائمة البريدية في هذا الموقع. ستحصل عندها آلياً في رسالة الكترونية على اعلانات حول المقالات والاخبار المقترحة للنشر. ',
	'info_confirmer_passe' => 'تأكيد كلمة السر الجديدة:',
	'info_conflit_edition_avis_non_sauvegarde' => 'تنبيه، تم تعديل الحقول التالية في مكان آخر. لذلك لم يتم تسجيل نعديلاتك.',
	'info_conflit_edition_differences' => 'الفروق:',
	'info_conflit_edition_version_enregistree' => 'الاصدار المسجل:',
	'info_conflit_edition_votre_version' => 'إصدارك:',
	'info_connexion_base' => 'محاولة الاتصال بقاعدة البيانات',
	'info_connexion_base_donnee' => 'الاتصال بقاعدة بياناتك',
	'info_connexion_ldap_ok' => 'نجح إتصال LDAP.</b><p> يمكنك الانتقال الى الخطوة التالية.</p>',
	'info_connexion_mysql' => 'الاتصال بخادم SQL',
	'info_connexion_ok' => 'نجح الاتصال.',
	'info_contact' => 'الاتصال',
	'info_contenu_articles' => 'محتوى المقالات',
	'info_contributions' => 'المساهمات',
	'info_creation_paragraphe' => 'لإنشاء فقرات يكفي ترك سطور فارغة.',
	'info_creation_rubrique' => 'قبل التمكن من كتابة مقالات،<br />يجب عليك إنشاء قسم واحد على الأقل.<br />',
	'info_creation_tables' => 'إنشاء جداول قاعدة البيانات',
	'info_creer_base' => '<b>قم بإنشاء</b>  قاعدة بيانات جديدة:',
	'info_dans_rubrique' => 'في القسم:	',
	'info_date_publication_anterieure' => 'تاريخ النشر السابق:',
	'info_date_referencement' => 'تاريخ تبويب هذا الموقع:',
	'info_derniere_etape' => 'إنتهى!',
	'info_descriptif' => 'الوصف:',
	'info_desinstaller_plugin' => 'يحذف البيانات ويعطل الملحقات',
	'info_discussion_cours' => 'النقاشات النشطة',
	'info_ecrire_article' => 'قبل التمكن من كتابة مقالات، يجب عليك إنشاء قسم واحد على الأقل.',
	'info_email_envoi' => 'العنوان الالكتروني للارسال (اختياري)',
	'info_email_envoi_txt' => 'ادخل هنا العنوان المطلوب استخدامه لبعث الرسائل (والا، سيتم استخدام عنوان المرسل اليه كعنوان ارسال):',
	'info_email_webmestre' => 'عنوان بريد المشرف على الموقع',
	'info_envoi_email_automatique' => 'إرسال البريد الآلي',
	'info_envoyer_maintenant' => 'إرسال الآن',
	'info_etape_suivante' => 'إنتقل الى الخطوة التالية',
	'info_etape_suivante_1' => 'يمكنك الانتقال الى الخطوة التالية.',
	'info_etape_suivante_2' => 'يمكنك الانتقال الى الخطوة التالية.',
	'info_exceptions_proxy' => 'استثناءات للجهاز الوكيل',
	'info_exportation_base' => 'نقل قاعدة البيانات الى @archive@',
	'info_facilite_suivi_activite' => 'لتسهيل متابعة أنشطة تحرير
الموقع، يرسل SPIP عبر البريد الى لائحة احد المحررين البريدية مثلاً،
الإعلان عن طلبات النشر وتصديق المقالات. يمكن ادخال عنوان او اكثر تفصل بينها فواصل.',
	'info_fichiers_authent' => 'ملف التحقق «.htpasswd»',
	'info_forums_abo_invites' => 'يحتوي موقعك على منتديات بالاشتراك. يشترك الزوار اذاً من الموقع العمومي.',
	'info_gauche_admin_tech' => '<b>لا يحق إلا لمسؤولي الموقع الوصول الى هذه الصفحة.</b><p> إنها توفر الوصول الى وظائف
متنوعة للصيانة التقنية. وتتطلب بعض هذه الوظائف عملية تحقق محددة
تحتاج الى الدخول الى الموقع عبر بروتوكول FTP .</p>',
	'info_gauche_admin_vider' => '<b>لا يحق إلا لمسؤولي الموقع الوصول الى هذه الصفحة.</b><p> إنها توفر الوصول الى وظائف
متنوعة للصيانة التقنية. وتتطلب بعض هذه الوظائف عملية تحقق محددة
تحتاج الى الدخول الى الموقع عبر بروتوكول FTP .</p>',
	'info_gauche_auteurs' => 'ستجد هنا جميع مؤلفي الموقع.
يدل لون رمز كل مؤلف على وضعه (مدير = أخضر؛ محرر = أصفر).',
	'info_gauche_auteurs_exterieurs' => 'المؤلفون الخارجيون، الذين لا يتمتعون بحق الدخول الى الموقع، معرّفون برمز أزرق؛
اما المؤلفون المحذوفون فبرمز رمادي.',
	'info_gauche_messagerie' => 'تتيح المراسلة تبادل الرسائل بين المحررين والحفاظ على المذكرات (لاستخدامك الشخصي) وعرض الإعلانات في الصفحة الرئيسية للمجال الخاص (إذا كنت مديراً).',
	'info_gauche_statistiques_referers' => 'تعرض هذه الصفحة قائمة <i>مواقع المصدر</i>، أي المواقع التي تحتوي على وصلات تقود الى موقعك، fبين البارحة واليوم فقط: فيتم تأصيل هذه القائمة كل 24 ساعة.',
	'info_gauche_visiteurs_enregistres' => 'ستجد هنا الزوار المسجلين
في مجال الموقع العام (المنتديات بالاشتراك).',
	'info_generation_miniatures_images' => 'إنشاء مصغرات الصور',
	'info_gerer_trad_objets' => '@objets@: إدارة روابط الترجمة',
	'info_hebergeur_desactiver_envoi_email' => 'بعض خدام المواقع يوقفون إرسال البريد الآلي
في أجهزتهم. في هذه الحال، لا يمكن تفعيل
وظائف SPIP التالية.',
	'info_hier' => 'البارحة:',
	'info_identification_publique' => 'هويتك العمومية...',
	'info_image_process' => 'الرجاء اختيار افضل طريقة لإنشاء المصغرات بالنقر على الصورة المناسبة.',
	'info_image_process2' => 'اذا لم تظهر اية صورة يكون جهاز الخدمة الذي يستضيف موقعك غير معدّ لاستخدام هذه الأدوات. اذا رغبت في استخدام هذه الوظائف، اتصل بالمسؤول التقني واطلب تثبيت أحد الملحقين «GD» او «Imagick».',
	'info_images_auto' => 'يتم حساب هذه الصور آلياً',
	'info_informations_personnelles' => 'المعلومات الشخصية',
	'info_inscription' => 'التسجيل في',
	'info_inscription_automatique' => 'تسجيل آلي للمحررين الجدد',
	'info_jeu_caractere' => 'طقم حروف الموقع',
	'info_jours' => 'يوم',
	'info_laisser_champs_vides' => 'ترك هذه الحقول فارغة)',
	'info_langues' => 'لغات الموقع',
	'info_ldap_ok' => 'تم تثبيت تحقق LDAP .',
	'info_lien_hypertexte' => 'وصلة هايبرتكست:',
	'info_liste_nouveautes_envoyee' => 'تم إرسال لائحة جديد الموقع',
	'info_liste_redacteurs_connectes' => 'قائمة المحررين المتصلين',
	'info_login_existant' => 'هذا المعرّف موجود سابقاً.',
	'info_login_trop_court' => 'معرّف الدخول قصيز جداً.',
	'info_login_trop_court_car_pluriel' => 'يجب ان يحتوي المعرّف @nb@ أحرف على الأقل.',
	'info_logos' => 'الرموز',
	'info_maximum' => 'الحد الأقصى:',
	'info_meme_rubrique' => 'في القسم نفسه',
	'info_message_en_redaction' => 'رسالتك قيد التحرير',
	'info_message_technique' => 'رسالة تقنية:',
	'info_messagerie_interne' => 'المراسلة الداخلية',
	'info_mise_a_niveau_base' => 'ترقية قاعدة بيانات SQL',
	'info_mise_a_niveau_base_2' => '{{تحذير!}} قمت بتثبيت إصدار
من ملفات SPIP {{أقدم}} من الإصدار الذي
كان موجوداً في هذا الموقع: قد تواجه خطر فقدان قاعدة البيانات
مما يحول دون عمل موقعك بشكل سليم.<br />{{إعادة تثبيت
ملفات SPIP.}}',
	'info_modification_enregistree' => 'تم تسجيل تعديلاتك',
	'info_modifier_auteur' => 'تغيير المؤلف:',
	'info_modifier_rubrique' => 'تعديل القسم:',
	'info_modifier_titre' => 'تغيير: @titre@',
	'info_mon_site_spip' => 'موقع SPIP',
	'info_moyenne' => 'المتوسط:',
	'info_multi_cet_article' => 'لغة هذا المقال:',
	'info_multi_langues_choisies' => 'الرجاء تحديد ادناه اللغات التي ستكون متوافرة لمحرري موقعك.
  لا يمكن ايقاف اللغات المستخدمة حالياً في موقعك (والظاهرة في اول القائمة).',
	'info_multi_objets' => '@objets@: تفعيل قائمة اللغات',
	'info_multi_secteurs' => '... للأقسام الموجودة في اصل الموقع فقط ',
	'info_nb_articles' => '@nb@ مقال',
	'info_nb_auteurs' => '@nb@ مؤلف',
	'info_nb_messages' => '@nb@ رسالة',
	'info_nb_mots_cles' => '@nb@ مفتاح',
	'info_nb_rubriques' => '@nb@ قسم',
	'info_nb_visiteurs' => '@nb@ زائر',
	'info_nom' => 'الإسم',
	'info_nom_destinataire' => 'إسم المرسل اليه',
	'info_nom_pas_conforme' => 'علامات html غير مسموح بها',
	'info_nom_site' => 'إسم موقعك',
	'info_nombre_articles' => '@nb_articles@ مقال،',
	'info_nombre_rubriques' => '@nb_rubriques@ قسم،',
	'info_nombre_sites' => '@nb_sites@ موقع،',
	'info_non_deplacer' => 'عدم التحريك...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'يستطيع SPIP إرسال إعلانات عن آخر الأخبار بانتظام.
(المقالات والأخبار المنشورة حديثاً).',
	'info_non_envoi_liste_nouveautes' => 'عدم إرسال قائمة بآخر الأخبار',
	'info_non_modifiable' => '</i>لا يمكن تغييره<i>',
	'info_non_suppression_mot_cle' => 'كلا لا أريد حذف هذا المفتاح.',
	'info_notes' => 'حواشي',
	'info_nouvel_article' => 'مقال جديد',
	'info_nouvelle_traduction' => 'ترجمة جديدة:',
	'info_numero_article' => 'المقال رقم:',
	'info_obligatoire_02' => '(إجباري)',
	'info_option_accepter_visiteurs' => 'قبول تسجيل الزوار من الموقع العمومي',
	'info_option_ne_pas_accepter_visiteurs' => 'رفض تسجيل الزوار من الموقع العمومي',
	'info_options_avancees' => 'الخيارات المتطورة',
	'info_ou' => 'أو...',
	'info_page_interdite' => 'صفحة محظورة',
	'info_par_nom' => 'حسب الاسم',
	'info_par_nombre_article' => 'حسب عدد المقالات',
	'info_par_statut' => 'حسب الوضع',
	'info_par_tri' => '’(حسب @tri@)’',
	'info_passe_trop_court' => 'كلمة السر قصيرة جداً.',
	'info_passe_trop_court_car_pluriel' => 'يجب ان تحتوي كلمة السر @nb@ أحرف على الأقل.',
	'info_passes_identiques' => 'كلمتا السر ليستا متطابقتان.',
	'info_plus_cinq_car' => 'أكثر من خمسة أحرف',
	'info_plus_cinq_car_2' => '(أكثر من خمسة أحرف)',
	'info_plus_trois_car' => '(أكثر من ثلاثة أحرف)',
	'info_popularite' => 'الشعبية: @popularite@؛ الزيارات: @visites@',
	'info_post_scriptum' => 'الملحق',
	'info_post_scriptum_2' => 'الملحق:',
	'info_pour' => 'لـ',
	'info_preview_texte' => 'من الممكن تفعيل العرض المسبق للعناصر التحريرية التي تتمتع على الاقل بوضعية «مقترح»، إضافة الى العناصر «قيد التحرير» العائدة للمؤلف المتصل. هل تتاح هذه الوظيفة للمدراء فقط او لجميع المحررين او تُعطل؟',
	'info_procedez_par_etape' => 'الرجاء إتباع الخطوة خطوة ',
	'info_procedure_maj_version' => 'يجب تنفيذ عملية الترقية لتكييف
قاعدة البيانات مع إصدار SPIP الجديد.',
	'info_proxy_ok' => 'نجح اختبار الجهاز الوكيل.',
	'info_ps' => 'ملاحظة',
	'info_publier' => 'نشر',
	'info_publies' => 'مقالاتك المنشورة',
	'info_question_accepter_visiteurs' => 'اذا كانت صفحات موقعك النموذجية تفسح المجال للزوار الذين لا يتمتعون بحق الدخول الى المجال الخاص لتسجيل انفسهم، قم بتفعيل الخيار التالي:',
	'info_question_inscription_nouveaux_redacteurs' => 'هل تسمح بتسجيل محررين جدد من
الموقع العمومي؟ إذا وافقت، سيتمكن الزوار من التسجيل
عبر إستمارة آلية والدخول الى المجال الخاص
لعرض مقالاتهم. <div class="notice">خلال عملية التسجيل،
يحصل المستخدمون على رسالة آلية
تزودهم ببيانات الدخول الى المجال الخاص. إلا ان بعض
 خدام المواقع يعطلون إرسال البريد الآلي في
أجهزتهم: في هذه الحال، لا يمكن تفعيل
التسجيل الآلي.</div>',
	'info_qui_edite' => '@nom_auteur_modif@ عمل على هذا المحتوى منذ @date_diff@ دقيقة ',
	'info_racine_site' => 'أصل الموقع',
	'info_recharger_page' => 'الرجاء إعادة تحميل الصفحة بعد لحظات.',
	'info_recherche_auteur_zero' => 'لا توجد نتائج لـ «@cherche_auteur@».',
	'info_recommencer' => 'الرجاء إعادة المحاولة.',
	'info_redacteur_1' => 'محرر',
	'info_redacteur_2' => 'يملك حق الدخول الى المجال الخاص (ينصح به)',
	'info_redacteurs' => 'محررون',
	'info_redaction_en_cours' => 'قيد التحرير',
	'info_redirection' => 'إعادة توجيه',
	'info_redirection_activee' => 'تم تفعيل إعادة التحويل.',
	'info_redirection_boucle' => 'محاولة إعادة توجيه مقال الى ذاته.',
	'info_redirection_desactivee' => 'تم حذف إعادة التحويل.',
	'info_refuses' => 'مقالاتك المرفوضة',
	'info_reglage_ldap' => 'خيارات: <b>ضبط جلب LDAP </b>',
	'info_renvoi_article' => '<b>إعادة توجيه.</b> هذا المقال يحيل الى الصفحة: ',
	'info_reserve_admin' => 'المدراء وحدهم يمكنهم تغيير هذا العنوان.',
	'info_restreindre_rubrique' => 'حصر الإدارة في القسم:',
	'info_resultat_recherche' => 'نتائج البحث:',
	'info_rubriques' => 'الأقسام',
	'info_rubriques_02' => 'الأقسام',
	'info_rubriques_trouvees' => 'الأقسام التي عثر عليها',
	'info_sans_titre' => 'بدون عنوان',
	'info_selection_chemin_acces' => '<b>حدد</b> أدناه مسار الدخول في الدليل:',
	'info_signatures' => 'التوقيعات',
	'info_site' => 'الموقع',
	'info_site_2' => 'الموقع:',
	'info_site_min' => 'الموقع',
	'info_site_reference_2' => 'موقع مبوب',
	'info_site_web' => 'الموقع:',
	'info_sites' => ' مواقع',
	'info_sites_lies_mot' => 'المواقع المبوبة المرتبطة بهذا المفتاح',
	'info_sites_proxy' => 'إستخدام جهاز وكيل',
	'info_sites_trouves' => 'المواقع التي عثر عليها',
	'info_sous_titre' => 'العنوان الفرعي:',
	'info_statut_administrateur' => 'مدير',
	'info_statut_auteur' => 'وضع هذا المؤلف:',
	'info_statut_auteur_2' => 'أنا',
	'info_statut_auteur_a_confirmer' => 'التسجيل المطلوب التأكد منه',
	'info_statut_auteur_autre' => 'وضعية اخرى:',
	'info_statut_redacteur' => 'محرر',
	'info_statut_utilisateurs_1' => 'الوضع الافتراضي للمستخدمين المجلوبين',
	'info_statut_utilisateurs_2' => 'قم باختيار الوضع المخصص للأشخاص الموجودين في دليل LDAP عندما سيتصلون للمرة الأولى. لاحقاً، يمكنك تغيير هذه القيمة لكل مؤلف على حدى.',
	'info_suivi_activite' => 'متابعة أنشطة التحرير',
	'info_surtitre' => 'عنوان المدخل:',
	'info_syndication_integrale_1' => 'يقدم موقعك ملفات ترخيص (انظر «<a href="@url@">@titre@</a>»).',
	'info_syndication_integrale_2' => 'هل ترغب في تقديم المقالات بكاملها او الاكتفاء بنشر ملخص من بضعة مئات من الكلمات؟',
	'info_table_prefix' => 'يمكنك تغيير بادئة اسماء جداول البيانات (هذا ضروري في حال تثبيت عدة مواقع لقاعدة بيانات واحدة). تكتب هذه البادئة بأحرف صغيرة بدون صوتيات ومسافات. ',
	'info_taille_maximale_images' => 'سيقوم SPIP بتفقد الحد الاقصى لحجم الصور التي يمكنه معالجتها (بملايين النقاط).<br /> لن يتم تصغير الصور التي تتعدى هذا الحد.',
	'info_taille_maximale_vignette' => 'الحد الأقصى لأبعاد المصغرات التي ينتجها النظام:',
	'info_terminer_installation' => 'يمكنك الآن إتمام عملية التثبيت العادية',
	'info_texte' => 'المادة',
	'info_texte_explicatif' => 'نص توضيحي',
	'info_texte_long' => '(المادة طويلة جداً: ستظهر بعدة أجزاء تتم إعادة تجميعها بعد النقر على الإدخال.)',
	'info_texte_message' => 'نص مشاركتك:',
	'info_texte_message_02' => 'نص الرسالة',
	'info_titre' => 'الموضوع:',
	'info_total' => 'المجموع:',
	'info_tous_articles_en_redaction' => 'كل المقالات قيد التحرير',
	'info_tous_articles_presents' => 'كل المقالات المنشورة في هذا القسم',
	'info_tous_articles_refuses' => 'كل المقالات المرفوضة',
	'info_tous_les' => 'كل:',
	'info_tout_site' => 'الموقع بالكامل',
	'info_tout_site2' => 'لم يُترجم المقال الى هذه اللغة.',
	'info_tout_site3' => 'تمت ترجمة المقال الى هذه اللغة لكن طرأت تعديلات على المقال المرجع في ما بعد. يجب تحديث الترجمة.',
	'info_tout_site4' => 'تمت ترجمة المقال الى هذه اللغة والترجمة حديثة.',
	'info_tout_site5' => 'المقال الاصلي.',
	'info_tout_site6' => '<b>تحذير:</b> المقالات الاصلية وحدها هي المعروضة.
الترجمات مرتبطة بالاصلي،
يلون يدل على حالتها:',
	'info_traductions' => 'الترجمات',
	'info_travail_colaboratif' => 'تحرير المقالات المشترك',
	'info_un_article' => 'مقال، ',
	'info_un_site' => 'موقع،',
	'info_une_rubrique' => 'قسم،',
	'info_une_rubrique_02' => 'قسم واحد',
	'info_url' => 'عنوان URL:',
	'info_url_proxy' => 'عنوان URL للجهاز الوكيل',
	'info_url_proxy_pas_conforme' => 'عنوان الجهاز الوكيل غير صالح.',
	'info_url_site_pas_conforme' => 'عنوان URL غير صالح.',
	'info_url_test_proxy' => 'عنوان URL للاختبار',
	'info_urlref' => 'وصلة هايبرتكست:',
	'info_utilisation_spip' => 'أصبح نظام النشر الآلي جاهزاً للاستخدام...',
	'info_visites_par_mois' => 'عرض حسب الشهر:',
	'info_visiteur_1' => 'زائر',
	'info_visiteur_2' => 'للموقع العمومي',
	'info_visiteurs' => 'الزوار',
	'info_visiteurs_02' => 'زوار الموقع العمومي',
	'info_webmestre_forces' => 'المشرفون محددون حالياً في <tt>@file_options@</tt>.',
	'install_adresse_base_hebergeur' => 'عنوان قاعدة البيانات التي خصصها لك المضيف',
	'install_connect_ok' => 'تم فعلاً تعريف قاعدة البيانات باسم جهاز الخدمة @connect@.',
	'install_echec_annonce' => 'الارجح ان التثبيت سيفشل او يؤدي الى موقع غير سليم...',
	'install_extension_mbstring' => 'لا يعمل SPIP مع:',
	'install_extension_php_obligatoire' => 'يتطلب SPIP ملحق php:',
	'install_login_base_hebergeur' => 'معرّف الدخول الذي خصصه لك المضيف',
	'install_nom_base_hebergeur' => 'اسم قاعدة البيانات الدي خصصه لك المضيف:',
	'install_pas_table' => 'قاعدة من دون جداول حالياً',
	'install_pass_base_hebergeur' => 'كلمة سر الاتصال التي خصصها لك المضيف',
	'install_php_extension' => 'الملحقات التالية غير موجودة: @extensions@',
	'install_php_version' => 'اصدار @version@ من PHP غير كاف(الحد الادنى = @minimum@)',
	'install_php_version_max' => 'PHP إصدار @version@ حديث جداً (الحد الأقصى = @maximum@)',
	'install_select_langue' => 'إختر لغة ثم انقر على الزر« التالي»  للبدء بعملية التثبيت.',
	'install_select_type_db' => 'تحديد نوع قاعدة البيانات:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'خادم قواعد البيانات الذي يوفره المضيف ',
	'install_table_prefix_hebergeur' => 'بادئة اسماء الجداول التي خصصها لك المضيف:',
	'install_tables_base' => 'جداول القاعدة',
	'install_types_db_connus' => 'يستطيع SPIP استخدام <b>MySQL</b> (الاكثر انتشاراً) و<b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'يتوافر دعم <b>PostgreSQL</b> أيضاً على سبيل الاختبار',
	'instituer_erreur_statut_a_change' => 'لقد تم تعديل الوضع من قبل',
	'instituer_erreur_statut_non_autorise' => 'لا يمكن اختيار هذا الوضع',
	'intem_redacteur' => 'محرر',
	'intitule_licence' => 'الرخصة',
	'item_accepter_inscriptions' => 'السماح بالتسجيل',
	'item_activer_messages_avertissement' => 'تفعيل رسائل التحذير',
	'item_administrateur_2' => 'مدير',
	'item_afficher_calendrier' => 'إظهار في الروزنامة',
	'item_autoriser_syndication_integrale' => 'نشر كامل المقالات في ملفات الترخيص',
	'item_choix_administrateurs' => 'المدراء',
	'item_choix_generation_miniature' => 'إنشاء مصغرات عن الصور آلياً.',
	'item_choix_non_generation_miniature' => 'عدم إنشاء مصغرات عن الصور.',
	'item_choix_redacteurs' => 'المحررون',
	'item_choix_visiteurs' => 'زوار الموقع العمومي',
	'item_creer_fichiers_authent' => 'إنشاء ملفات .htpasswd',
	'item_login' => ' المعرّف',
	'item_messagerie_agenda' => 'تفعيل المراسلة والمفكرة',
	'item_mots_cles_association_articles' => 'المقالات',
	'item_mots_cles_association_rubriques' => 'الأقسام',
	'item_mots_cles_association_sites' => 'المواقع المبوبة او المرخصة.',
	'item_non' => 'كلا',
	'item_non_accepter_inscriptions' => 'عدم السماح بالتسجيل',
	'item_non_activer_messages_avertissement' => 'تعطيل رسائل التحذير',
	'item_non_afficher_calendrier' => 'عدم إظهار في الروزنامة',
	'item_non_autoriser_syndication_integrale' => 'الاكتفاء بنشر ملخص',
	'item_non_creer_fichiers_authent' => 'عدم إنشاء هذه الملفات',
	'item_non_messagerie_agenda' => 'تعطيل المراسلة والمفكرة',
	'item_non_publier_articles' => 'عدم نشر المقالات قبل تاريخها.',
	'item_nouvel_auteur' => 'مؤلف جديد',
	'item_nouvelle_rubrique' => 'قسم جديد',
	'item_oui' => 'نعم',
	'item_publier_articles' => 'نشر المقالات مهما كان تاريخها.',
	'item_reponse_article' => 'الرد على المقال',
	'item_visiteur' => 'زائر',

	// J
	'jour_non_connu_nc' => 'غير معروف',

	// L
	'label_bando_outils' => 'شريط الأدوات',
	'label_bando_outils_afficher' => 'عرض الأدوات',
	'label_bando_outils_masquer' => 'إخفاء الأدوات',
	'label_choix_langue' => 'حدد لغتك',
	'label_nom_fichier_connect' => 'أدخل الاسم الذي يستخدمه هذا الخادم',
	'label_slogan_site' => 'شعار الموقع',
	'label_taille_ecran' => 'عرض الشاشة',
	'label_texte_et_icones_navigation' => 'قائمة التصفح',
	'label_texte_et_icones_page' => 'عرض في الصفحة',
	'ldap_correspondance' => 'استلام من الحقل @champ@',
	'ldap_correspondance_1' => 'استلام حقول LDAP',
	'ldap_correspondance_2' => 'لكل من حقول SPIP التالية، حدد اسم حقل LDAP المناسب. يمكن ترك حقل فارغ، استخدام المسافات او الفواصل لتجربة عدة حقول LDAP.',
	'lien_ajouter_auteur' => 'إضافة هذا المؤلف',
	'lien_ajouter_une_rubrique' => 'إضافة هذا القسم',
	'lien_email' => 'البريد الالكتروني',
	'lien_nom_site' => 'إسم الموقع:',
	'lien_rapide_contenu' => 'الذهاب الى المحتوى',
	'lien_rapide_navigation' => 'الذهاب اى التصفح',
	'lien_rapide_recherche' => 'الذهاب الى البحث',
	'lien_retirer_auteur' => 'حذف المؤلف',
	'lien_retirer_rubrique' => 'سحب القسم',
	'lien_retirer_tous_auteurs' => 'إزالة جميع المؤلفين',
	'lien_retirer_toutes_rubriques' => 'سحب كل الأقسام',
	'lien_site' => 'الموقع',
	'lien_tout_decocher' => 'إزالة تحديد الكل',
	'lien_tout_deplier' => 'بسط الكل',
	'lien_tout_replier' => 'طي الكل',
	'lien_tout_supprimer' => 'حذف الكل',
	'lien_trier_nom' => 'فرز حسب الإسم  ',
	'lien_trier_nombre_articles' => 'فرز حسب عدد المقالات',
	'lien_trier_statut' => 'فرز حسب الوضع',
	'lien_voir_en_ligne' => 'عرض مباشر:',
	'logo_article' => 'رمز المقال',
	'logo_auteur' => 'رمز المؤلف',
	'logo_rubrique' => 'رمز القسم',
	'logo_site' => 'رمز هذا الموقع',
	'logo_standard_rubrique' => 'رمز الأقسام القياسي',
	'logo_survol' => 'رمز الحوم',

	// M
	'menu_aide_installation_choix_base' => 'إختيار قاعدة البيانات',
	'module_fichier_langue' => 'ملف اللغة',
	'module_raccourci' => 'اختصار',
	'module_texte_affiche' => 'النص المعروض',
	'module_texte_explicatif' => 'يمكن ادراج الاختصارات التالية في صفحات الموقع النموذجية. سوف تُترجم آلياً في مختلف اللغات التي يتوافر لها ملف لغة.',
	'module_texte_traduction' => 'ملف اللغة «@module@» متوافر بـ:',
	'mois_non_connu' => 'غير معروف',

	// N
	'nouvelle_version_spip' => 'ترقية SPIP رقم @version@ متوافرة الآن',
	'nouvelle_version_spip_majeure' => 'إصدار جديد من رقم @version@ من SPIP متوافر الآن',

	// O
	'onglet_contenu' => 'المحتوى',
	'onglet_declarer_une_autre_base' => 'الاعلان عن قاعدة اخرى',
	'onglet_discuter' => 'النقاش',
	'onglet_interactivite' => 'التفاعلية',
	'onglet_proprietes' => 'الخصائص',
	'onglet_repartition_actuelle' => 'حالياً',
	'onglet_sous_rubriques' => 'الأقسام الفرعية',

	// P
	'page_pas_proxy' => 'لا يجب ان تمر هذه الصفحة عبر جهاز بروكسي',
	'pas_de_proxy_pour' => 'لدى الضرورة، حدد الاجهزة او النطاقات التي لا يجب ان ينطبق عليها الوكيل (مثلاً: @exemple@) ',
	'phpinfo' => 'إعدادات PHP',
	'plugin_charge_paquet' => 'تحميل رزمة @name@',
	'plugin_charger' => 'تحميل',
	'plugin_erreur_charger' => 'خطأ: لا يمكن تحميل @zip@',
	'plugin_erreur_droit1' => 'المجلد <code>@dest@</code> لا يسمح بالكتابة فيه.',
	'plugin_erreur_droit2' => 'الرجاء التأكد من الامتيازات على هذا المجلد (وانشائه اذا اقتضى الامر)، او تثبيت الملفات عبر FTP.',
	'plugin_erreur_zip' => 'فشل pclzip: خطأ @status@',
	'plugin_etat_developpement' => 'قيد التطوير',
	'plugin_etat_experimental' => 'اختباري',
	'plugin_etat_stable' => 'ثابت',
	'plugin_etat_test' => 'قيد الاختبار',
	'plugin_impossible_activer' => 'لا يمكن تفعيل الملحق @plugin@',
	'plugin_info_automatique1' => 'اذا اردت السماح بالتثبيت الآلي للملحقات، الرجاء:',
	'plugin_info_automatique1_lib' => 'أذا رغبت في السماح بالتثبيت الآلي لهذه المكتبة، يرجى:',
	'plugin_info_automatique2' => 'انشاء المجلد <code>@rep@</code>،',
	'plugin_info_automatique3' => 'التأكد من ان جهاز الخدمة يمكنه الكتابة في هذا المجلد.',
	'plugin_info_automatique_creer' => 'يتم انشاؤه في اصل الموقع.',
	'plugin_info_automatique_exemples' => 'أمثلة:',
	'plugin_info_automatique_ftp' => 'يمكنك تثبيت الملحقات بواسطة FTP في المجلد <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'بعض الملحقات تتطلب ايضاً القدرة على تحميل ملفات في مجلد <code>lib/</code> الذي يتم انشاؤه في اصل الموقع اذا لزم الامر.',
	'plugin_info_automatique_liste' => 'لوائح الملحقات:',
	'plugin_info_automatique_liste_officielle' => 'الملحقات الرسمية',
	'plugin_info_automatique_liste_update' => 'تحديث اللوائح',
	'plugin_info_automatique_ou' => 'او...',
	'plugin_info_automatique_select' => 'اختر احد الملحقات ادناه: سيقوم SPIP بتحميله وتثبيته في المجلد <code>@rep@</code>. اذا كان هذا الملحق موجوداً سوف يتم تحديثه.',
	'plugin_info_credit' => 'الحقوق',
	'plugin_info_erreur_xml' => 'تعريف هذا الملحق غير صحيح',
	'plugin_info_install_ok' => 'نجح التثبيت',
	'plugin_info_necessite' => 'يتطلب:',
	'plugin_info_non_compatible_spip' => 'لا يتوافق هذا الملحق مع هذا الإصدار من SPIP',
	'plugin_info_plugins_dist_1' => 'تم تحميل الإضافات أدناه وتفعيلها في مجلد @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'لا يمكن إيقافها.',
	'plugin_info_telecharger' => 'للتحميل من @url@ والتثبيت في @rep@',
	'plugin_info_upgrade_ok' => 'نجحت الترقية',
	'plugin_librairies_installees' => 'المكتبات المثبتة',
	'plugin_necessite_extension_php' => 'يتطلب ملحق PHP @plugin@ إصدار @version@.',
	'plugin_necessite_extension_php_sans_version' => 'يتطلب ملحق  PHP @plugin@',
	'plugin_necessite_lib' => 'هذا الملحق يتطلب المكتبة @lib@',
	'plugin_necessite_php' => 'يتطلب @plugin@ إصدار @version@.',
	'plugin_necessite_plugin' => 'يتطلب الملحق @plugin@ بالاصدار @version@.',
	'plugin_necessite_plugin_sans_version' => 'يتطلب الملحق @plugin@',
	'plugin_necessite_spip' => 'يتطلب SPIP باصدار @version@ على الاقل.',
	'plugin_source' => 'المصدر:',
	'plugin_titre_automatique' => 'تثبيت آلي',
	'plugin_titre_automatique_ajouter' => 'إضافة ملحقات',
	'plugin_titre_installation' => 'تثبيت الملحق @plugin@',
	'plugin_titre_modifier' => 'ملحقاتي',
	'plugin_utilise_extension_php' => 'إصدار ملحق  PHP @plugin@ يجب ان يكون @version@.',
	'plugin_utilise_php' => 'إصدار @plugin@ يجب ان يكون @version@.',
	'plugin_utilise_plugin' => 'إصدار الملحق @plugin@ يجب ان يكون @version@.',
	'plugin_zip_active' => 'تابع للتفعيل',
	'plugin_zip_adresse' => 'ادخل ادناه عنوان ملف zip لملحق مطلوب تحميله او عنوان لائحة ملاحق.',
	'plugin_zip_adresse_champ' => 'عنوان الملحق او اللائحة ',
	'plugin_zip_content' => 'يحتوي الملفات التالية (@taille@)، بانتظار تثبيتها في المجلد <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'تم ازالة ضغط الملف @zip@ وتثبيته.',
	'plugin_zip_installe_rep_finie' => 'تم ازالة ضغط الملف @zip@ وتثبيته في المجلد @rep@',
	'plugin_zip_installer' => 'بمكنك الآن تثبيته.',
	'plugin_zip_telecharge' => 'تم تحميل الملف @zip@',
	'plugins_actif_aucun' => 'لا يوجد ملحقات نشطة',
	'plugins_actif_un' => 'ملحق واحد نشط.',
	'plugins_actifs' => '@count@ ملحق ناشط.',
	'plugins_actifs_liste' => 'النشطة',
	'plugins_compte' => '@count@ ملحق',
	'plugins_disponible_un' => 'ملحق واحد متاح.',
	'plugins_disponibles' => '@count@ ملحق متوافر.',
	'plugins_erreur' => 'خطأ في الملحقات: @plugins@',
	'plugins_liste' => 'لائحة الملحقات',
	'plugins_liste_dist' => 'الملحقات المقفلة',
	'plugins_recents' => 'أحدث الملحقات.',
	'plugins_tous_liste' => 'الكل',
	'plugins_vue_hierarchie' => 'الهرمية',
	'plugins_vue_liste' => 'لائحة',
	'protocole_ldap' => 'إصدار البروتوكول:',

	// Q
	'queue_executer_maintenant' => 'تنفيذ الآن',
	'queue_info_purger' => 'يمكنك حذف كل الأعمال في الانتظار وتأصيل لائحة الأعمال الدورية',
	'queue_nb_jobs_in_queue' => '@nb@ عمل بالانتظار',
	'queue_next_job_in_nb_sec' => 'العمل القادم خلال @nb@ ثانية',
	'queue_no_job_in_queue' => 'لا توجد أعمال بالانتظار',
	'queue_one_job_in_queue' => 'عمل واحد بالانتظار',
	'queue_priorite_tache' => 'الأفضلية',
	'queue_purger_queue' => 'تأصيل لائحة الأعمال',
	'queue_titre' => 'أعمال الخلفية',

	// R
	'repertoire_plugins' => 'دليل:',
	'required' => '(إجباري)',

	// S
	'sans_heure' => 'بدون توقيت الساعات',
	'statut_admin_restreint' => 'إدارة محدودة',
	'statut_webmestre' => 'المشرف على الموقع',

	// T
	'tache_cron_asap' => 'مهمة CRON @function@ (في أسرع وقت)',
	'tache_cron_secondes' => 'مهمةCRON @function@ (كل @nb@ ثانية)',
	'taille_cache_image' => 'تحتل الصور التي حسبها SPIP آلياً (مصغرات مستندات، عناوين معروضة كصور، دالات رياضية بتنسيق TeX...) مساحة اجمالية تبلغ @taille@ في الدليل @dir@.',
	'taille_cache_infinie' => 'لا يضع هذا الموقع اي حدود لحجم دليل الذاكرة المخبأة.',
	'taille_cache_maxi' => 'يحاول SPIP الحد من حجم دليل الذاكرة المخبأة في هذا الموقع لكي لا يتعدى <b>@octets@</b> من البيانات.',
	'taille_cache_moins_de' => 'حجم الذاكرة المخبأة أقل من @octets@.',
	'taille_cache_octets' => 'يبلغ حجم الذاكرة المخبأة حالياً @octets@ تقريباً.',
	'taille_cache_vide' => 'الذاكرة المخبأة فارغة.',
	'taille_repertoire_cache' => 'حجم دليل الذاكرة المخبأة',
	'text_article_propose_publication' => 'مقال معروض للنشر.',
	'texte_acces_ldap_anonyme_1' => 'بعض خدام LDAP تمنع الدخول المغفل. في هذه الحال عليك بإدخال بيانات دخول أولية لتتمكن من البحث عن معلومات في الدليل لاحقاً. إلا أنه، في معظم الأحيان، يمكن ترك الحقول التالية فارغة.',
	'texte_admin_effacer_01' => 'يقوم هذا الأمر بحذف  كامل محتوى قاعدة البيانات،
بما في ذلك كل  وسائط الوصول للمحررين والمدراء. بعد تنفيذه، يتحتم عليك
إعادة تثبيت SPIP لإعادة إنتاج قاعدة جديدة ووسيط دخول أول مدير.',
	'texte_adresse_annuaire_1' => 'إذا كان دليلك مثبت على الجهاز نفسه الذي يحتوي موقعك، فإنه على الأرجح «localhost»)).',
	'texte_ajout_auteur' => 'تمت إضافة المؤلف التالي الى المقال:',
	'texte_annuaire_ldap_1' => 'إذا كان لديك إمكتان وصول الى دليل LDAP، يمكنك استخدامه لجلب المستخدمين آلياً الى SPIP.',
	'texte_article_statut' => 'هذا المقال:',
	'texte_article_virtuel' => 'مقال إفتراضي',
	'texte_article_virtuel_reference' => '<b>مقال إفتراضي: <b/>مقال مبوّب في موقع SPIP لديك، لكنه موجه الى عنوان آخر. لإلغاء التوجيه، قم بحذف العنوان أعلاه.',
	'texte_aucun_resultat_auteur' => 'لا توجد نتائج لـ "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'يمكن لهذا الموقع رصد قائمة المحررين المتصلين بشكل دائم مما يتيح لك تبادل الرسائل في الوقت الحقيقي. يمكنك التقرير بعدم الظهور في هذه القائمة (وبالتالي تكون «مخفياً» بالنسبة للمستخدمين الآخرين).',
	'texte_auteurs' => 'المؤلفون',
	'texte_choix_base_1' => 'حدد قاعدة بياناتك:',
	'texte_choix_base_2' => 'يحتوي خادم SQL على عدة قواعد بيانات.',
	'texte_choix_base_3' => '<b>حدد</b> أدناه القاعدة التي خصصها مضيفك لك:',
	'texte_choix_table_prefix' => 'بادئة الجداول:',
	'texte_compte_element' => 'عنصر@count@',
	'texte_compte_elements' => 'عنصر@count@',
	'texte_conflit_edition_correction' => 'الرجاء التدقيق ادناه في الفوارق بين إصداري النص. يمكنك ايضاً تسخ تعديلاتك ثم البدء من جديد.',
	'texte_connexion_mysql' => 'راجع المعلومات التي زودك بها مضيفك:  من المفترض ان تجد فيها خادم قاعدة البيانات وبيانات اتصالك الشخصية بالقاعدة.',
	'texte_contenu_article' => '(محتوى المقال في بضع كلمات.)',
	'texte_contenu_articles' => 'اعتماداً على تصميم موقعك، يمكنك اختيار
عدم استخدام بعض عناصر المقالات.
إستخدم القائمة التالية لاختيار العناصر التي ستكون متاحة.',
	'texte_crash_base' => 'إذا حصل عطل في
قاعدتك، يمكنك محاولة إصلاحها
آلياً.',
	'texte_creer_rubrique' => 'قبل التمكن من كتابة مقالات،<br />يجب عليك إنشاء قسم واحد على الأقل.',
	'texte_date_creation_article' => 'تاريخ إنشاء المقال:',
	'texte_date_creation_objet' => 'تاريخ الانشاء:', # on ajoute le &quot;:&quot;
	'texte_date_publication_anterieure' => 'تاريخ النشر السابق:',
	'texte_date_publication_anterieure_nonaffichee' => 'إخفاء تاريخ النشر السابق.',
	'texte_date_publication_article' => 'تاريخ النشر:',
	'texte_date_publication_objet' => 'تاريخ النشر:',
	'texte_definir_comme_traduction_rubrique' => 'هذا القسم هو ترجمة للقسم رقم:',
	'texte_descriptif_rapide' => 'وصف مقتضب',
	'texte_effacer_base' => 'حذف قاعدة بيانات SPIP',
	'texte_effacer_statistiques' => 'حذف الاحصاءات',
	'texte_en_cours_validation' => 'المقالات والأخبار التالية معروضة للنشر.',
	'texte_enrichir_mise_a_jour' => 'يمكنك استخدام «إختصارات الكتابة» لتحسين مظهر مادتك.',
	'texte_fichier_authent' => '<b>هل يقوم SPIP بإنشاء الملفات الخاصة<tt>.htpasswd</tt>
و<tt>.htpasswd-admin</tt> في المجلد @dossier@؟</b>
<p>تستخدم هذه الملفات للحد من دخول المؤلفين
 والمدراء الى اجزاء اخرى من الموقع
(تطبيقات إحصائية خارجية مثلاً).</p><p>
إذا كنت لا تحتاج الى هذه الملفات يمكنك الإبقاء على القيمة
الافتراضية لهذا الخيار (عدم إنشاء 
الملفات).</p>',
	'texte_informations_personnelles_1' => 'سيزودك النظام الآن بدخول شخصي الى الموقع.',
	'texte_informations_personnelles_2' => '(ملاحظة: هذه إعادة تثبيت، اذا كان دخولك لا يزال يعمل، يمكنك',
	'texte_introductif_article' => '(نص تقديمي للمقال)',
	'texte_jeu_caractere' => 'يستحسن استخدام طقم الحروف الشامل (<tt>utf-8</tt>): يسمح هذا الطقم بعرض نصوص بجميع اللغات ولا يتسبب بمشاكل توافق مع برامج التصفح الحديثة.',
	'texte_jeu_caractere_3' => 'موقعك يستخدم حالياً طقم الحروف:',
	'texte_jeu_caractere_4' => 'اذا كان ذلك لا يتناسب مع واقع بياناتك (من جراء استرجاع نسخة احتياطية من القاعدة مثلاً) او اذا كنت <strong>تباشر في اطلاق هذا الموقع</strong> وترغب في استخدام طقم حروف آخر، الرجاء تحديد هذا الطقم هنا:',
	'texte_login_ldap_1' => ')أتركه فارغاً للدخول المغفل أو قم بإدخال المسار الكامل، مثلاً «<tt>uid=salim, ou=users, dc=mon-domaine, dc=com</tt>»).',
	'texte_login_precaution' => 'تحذير! هذا هو المعرّف الذي تتصل من خلاله الآن.
إستخدم هذه الاستمارة بحذر...',
	'texte_messagerie_agenda' => 'يتيح نظام مراسلة لمحرري الموقع التواصل بين بعضهم مباشرة في المجال الخاص. وهو مرتبط بالمفكرة.',
	'texte_mise_a_niveau_base_1' => 'لقد قمت بتحديث ملفات SPIP.
يجب الآن تحديث قاعدة بيانات
الموقع.',
	'texte_modifier_article' => 'تعديل المقال:',
	'texte_multilinguisme' => 'اذا احتجت الى إدارة عناصر متعددة اللغات وبتصفح معقّد، يمكنك إضافة قائمة اختيار اللغة في هذه العناصر تتماشى مع تنظيم موقعك.',
	'texte_multilinguisme_trad' => 'يمكنك ايضاً تفعيل نظام لإدارة الروابط بين الترجمات المختلفة لبعض العناصر.',
	'texte_non_compresse' => 'غير مضغوط (خادمك لا يدعم هذه الوظيفة)',
	'texte_nouvelle_version_spip_1' => 'لقد قمت بتثبيت إصدار جديد من SPIP.',
	'texte_nouvelle_version_spip_2' => 'هذا الإصدار الجديد يتطلب تحديثاً أكثر عمقاً من المعتاد. إذا كنت مسؤولاً عن هذا الموقع، الرجاء حذف الملف @connect@ وإعادة تنفيذ عملية التثبيت من أجل تحديث بيانات الاتصال بالقاعدة. <p> ( ملاحظة: إذا نسيت بيانات الاتصال، أنظر في الملف @connect@ قبل حذفه...)</p>',
	'texte_operation_echec' => 'عد الى الصفحة السابقة وحدد قاعدة بيانات أخرى أو قم بإنشاء قاعدة جديدة. تأكد من المعلومات التي حصلت عليها من مضيفك',
	'texte_plus_trois_car' => 'أكثر من ثلاثة أحرف',
	'texte_plusieurs_articles' => 'تم العثور على عدة مؤلفين لـ "@cherche_auteur@":',
	'texte_port_annuaire' => '(القيمة الافتراضية مناسبة عموماً).',
	'texte_presente_plugin' => 'تعرض هذه الصفحة لائحة بالملحقات المتوافرة في موقعك. يمكنك تفعيل الملحقات التي تريدها بالنقر على الخانات المناسبة لها.',
	'texte_proposer_publication' => 'عندما تنتهي من مقالك،<br />يمكنك عرضه للنشر.',
	'texte_proxy' => 'في بعض الحالات (انترانت، شبكات محمية...)، لا يمكن الوصول الى المواقع البعيدة (توثيق SPIP، المواقع المرخصة...) الا من خلال <b>جهاز وكيل</b>. اذا لزم الامر، حدد ادناه عنوان الجهاز على الشكل @proxy_en_cours@. بشكل عام اترك هذه الخانة فارغة.',
	'texte_publication_articles_post_dates' => 'كيف يجب على SPIP  ان يتصرف بالنسبة للمقالات التي
تم تحديد تاريخها
	في المستقبل؟',
	'texte_rappel_selection_champs' => '[لا تنسى ان تحدد هذا الحقل بشكل صحيح]',
	'texte_recalcul_page' => 'إذا كنت ترغب
في تحديث صفحة واحدة، الأحرى بك تنفيذ هذه العملية من الموقع العمومي باستخدام زر «تحديث» الصفحة.
',
	'texte_recuperer_base' => 'إصلاح قاعدة البيانات',
	'texte_reference_mais_redirige' => 'مقال مبوّب في موقع SPIP لديك، لكنه موجه الى عنوان آخر.',
	'texte_requetes_echouent' => '<b>عندما يفشل بعض إستفسارات SQL
بشكل منتظم ومتكرر دون أي سبب ظاهر، قد يكون
العطل في قاعدة البيانات 
  نفسها.</b><p>
يتمتع خادم SQL بوظيفة إصلاح الجداول اذا اصابها عطل
طارئ. يمكنك هنا محاولة تنفيذ هذا الإصلاح؛ في
حال فشل المحاولة يجب عليك الاحتفاظ بنسخة مما تعرضه الشاشة لأنه قد يحتوي
أدلة عن المشكلة...</p><p>
إذا استمرت المشكلة إتصل
  بمضيف موقعك.</p>',
	'texte_selection_langue_principale' => 'أدناه يمكنك تحديد «اللغة الأساسية » للموقع. لحسن الحظ لن يفرض عليك هذا الخيار تحرير مقالاتك باللغة المحددة، الا انه يحدد:
<ul><li> تنسيق التواريخ الافتراضي في الموقع العام؛</li>
<ul><li> طبيعة محرك الكتابة الذي يجب على SPIP استخدامه لتنسيق النصوص؛</li>
<ul><li> اللغة المستخدمة في إستمارات الموقع العام؛</li>
<ul><li> اللغة الافتراضية التي يعرضها المجال الخاص. </li></ul>',
	'texte_sous_titre' => 'العنوان الفرعي',
	'texte_statistiques_visites' => '(القضبان الداكنة: الأحد / المنحنيات الداكنة: التطور الوسطي)',
	'texte_statut_attente_validation' => 'بانتظار التصديق',
	'texte_statut_publies' => 'منشور',
	'texte_statut_refuses' => 'مرفوض',
	'texte_suppression_fichiers' => 'إستخدم هذا الأمر لحذف كل الملفات الموجودة
في الذاكرة المخبأة. ويتيح لك ذلك، من بين أمور أخرى، فرض تحديث كل الصفحات في حال
قمت بإدخال تعديلات مهمة على الرسوم أو التصميم في الموقع. ',
	'texte_sur_titre' => 'العنوان المدخل',
	'texte_table_ok' => ': هذا الجدول صالح.',
	'texte_tentative_recuperation' => 'محاولة إصلاح',
	'texte_tenter_reparation' => 'محاولة إصلاح قاعدة البيانات',
	'texte_test_proxy' => 'لتجربة الجهاز الوكيل، قم بإدخال عنوان موقع 
				ترغب في زيارته.',
	'texte_titre_02' => 'الإسم:',
	'texte_titre_obligatoire' => '<b>العنوان</b> [إجباري]',
	'texte_travail_article' => '@nom_auteur_modif@ تعامل مع هذا المقال منذ @date_diff@ دقيقة',
	'texte_travail_collaboratif' => 'كثيراً ما يحدث أن يتعاون
عدة محررين في تحرير المقال نفسه، فيمكن
للنظام أن يعرض المقالات «المفتوحة» حديثاً
بهدف تجنب إدخال تعديلات متزامنة عليها.
هذا الخيار متوقف افتراضياً
لتجنب عرض رسائل تحذير
مفاجئة.',
	'texte_vide' => 'فارغ',
	'texte_vider_cache' => 'تفريغ الذاكرة المخبأة',
	'titre_admin_tech' => 'صيانة تقنية',
	'titre_admin_vider' => 'صيانة تقنية',
	'titre_ajouter_un_auteur' => 'إضافة مؤلف',
	'titre_ajouter_un_mot' => 'إضافة مفتاح',
	'titre_cadre_afficher_article' => 'إظهار المقالات',
	'titre_cadre_afficher_traductions' => 'عرض وضع الترجمات للغات التالية:',
	'titre_cadre_ajouter_auteur' => 'إضافة مؤلف:',
	'titre_cadre_interieur_rubrique' => 'في القسم',
	'titre_cadre_numero_auteur' => 'مؤلف رقم',
	'titre_cadre_numero_objet' => '@objet@ رقم:',
	'titre_cadre_signature_obligatoire' => '<b>التوقيع<b> [إجباري]<br />',
	'titre_config_contenu_notifications' => 'تبليغات',
	'titre_config_contenu_prive' => 'في المجال الخاص',
	'titre_config_contenu_public' => 'في الموقع العمومي',
	'titre_config_fonctions' => 'إعداد الموقع',
	'titre_config_langage' => 'إعداد اللغة',
	'titre_configuration' => 'إعداد الموقع',
	'titre_configurer_preferences' => 'إعداد التفضيلات',
	'titre_configurer_preferences_menus' => 'إعداد تفضيلات القوائم',
	'titre_conflit_edition' => 'تضارب لدى التحرير',
	'titre_connexion_ldap' => 'خيارات: <b>إتصالLDAP </b>',
	'titre_groupe_mots' => 'مجموعة مفاتيح:',
	'titre_identite_site' => 'هوية الموقع',
	'titre_langue_article' => 'لغة المقال',
	'titre_langue_rubrique' => 'لغة القسم',
	'titre_langue_trad_article' => 'لغة المقال وترجماته',
	'titre_les_articles' => 'المقالات',
	'titre_messagerie_agenda' => 'المراسلة والمفكرة',
	'titre_naviguer_dans_le_site' => 'تصفح الموقع...',
	'titre_nouvelle_rubrique' => 'قسم جديد',
	'titre_numero_rubrique' => 'قسم رقم:',
	'titre_page_articles_edit' => 'تعديل: @titre@',
	'titre_page_articles_page' => 'المقالات',
	'titre_page_articles_tous' => 'الموقع بالكامل',
	'titre_page_calendrier' => 'روزنامة @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'إعداد الموقع',
	'titre_page_delete_all' => 'حذف تام ونهائي',
	'titre_page_recherche' => 'نتائج البحث @recherche@',
	'titre_page_statistiques_referers' => 'الاحصاءات (الوصلات الآتية)',
	'titre_page_upgrade' => 'ترقية SPIP',
	'titre_preference_menus_favoris' => 'قائمة المفضلات',
	'titre_publication_articles_post_dates' => 'نشر المقالات المؤجلة',
	'titre_reparation' => 'إصلاح',
	'titre_suivi_petition' => 'متابعة العرائض',
	'tls_ldap' => 'أمان طبقة النقل:',
	'trad_article_traduction' => 'كل اصدارات هذا المقال:',
	'trad_delier' => 'ايقاف الربط هذا بهذه الترجمات',
	'trad_lier' => 'هذا المقال هو ترجمة للمقال رقم:',
	'trad_new' => 'كتابة ترجمة جديدة',

	// U
	'utf8_convert_erreur_orig' => 'خطأ: طقم الحروف @charset@ غير مدعوم.',

	// V
	'version' => 'الإصدار:'
);
